==> hoteldruid-mod-pt_2.1.2-2.zip: pt/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "O sobrenome será alterado de"; break;
case "a":  					$messaggio = "para"; break;
case "Il nome verrà cambiato da":  		$messaggio = "O nome  será alterado de"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "O sexo será alterado para"; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "A data de nascimento será alterada de"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "O número de telefone será alterado de"; break;
case "La via  verrà cambiata da":  		$messaggio = "A rua será alterada de"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "O Número de casa será alterado de"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "A cidade de residência será alterada de"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "O país de residência será alterado de"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "O CEP será alterado de"; break;
case "Il fax verrà cambiato da":  		$messaggio = "O fax será alterado de"; break;
case "L' email verrà cambiata da":  		$messaggio = "O e-mail será alterado de"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "O número do 2º telefone será alterado de"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "O número do 3º telefone será alterado de"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "O <b>comentário</b> será alterado"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "O <b>nome</b> será apagado"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "A <b>data de nascimento</b> será apagada"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "O <b>telefone</b> será apagado"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "A <b>rua</b> será apagada"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "O <b>número de casa</b> será apagado"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "A <b>cidade de residência</b> será apagada"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "O <b>país de residência</b> será apagado"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "O <b>CEP</b> será apagado"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "O <b>fax</b> será apagado"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "O <b>e-mail</b> será apagado"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "O <b>número do 2º telefone</b> será apagado"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "O <b>número do 3º telefone</b> será apagado"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Il cliente":  				$messaggio = "O cliente"; break;
case "è stato modificato":  			$messaggio = "foi alterado"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Modifica i dati del cliente":  		$messaggio = "Alterar os dados do cliente"; break;
case "Cognome":  				$messaggio = "Sobrenome"; break;
case "cambia in":  				$messaggio = "alterar para"; break;
case "Nome":  					$messaggio = "Nome"; break;
case "cancella":  				$messaggio = "apagar"; break;
case "Sesso":  					$messaggio = "Sexo"; break;
case "Data di nascita":  			$messaggio = "Data de nascimento"; break;
case "Telefono":  				$messaggio = "Telefone"; break;
case "Via":  					$messaggio = "Rua"; break;
case "Piazza":  				$messaggio = "Praça"; break;
case "Viale":  					$messaggio = "Avenida"; break;
case "Piazzale":  				$messaggio = "Bairro"; break;
case "Vicolo":  				$messaggio = "Estrada"; break;
case "Numero civico":  				$messaggio = "Número de casa"; break;
case "Città di residenza":  			$messaggio = "Cidade de residência"; break;
case "Nazione di residenza":  			$messaggio = "País de residência"; break;
case "CAP":  					$messaggio = "CEP"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "2° telefono":  				$messaggio = "2º telefone"; break;
case "3° telefono":  				$messaggio = "3º telefone"; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "documento di tipo":  			$messaggio = "documento do tipo"; break;
case "visualizza":  				$messaggio = "visualizar"; break;
case "visualizza il documento":  		$messaggio = "visualizar documento"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reservas do cliente"; break;
case "nel":  					$messaggio = "em"; break;
case "Cognome_del_cliente":  			$messaggio = "Sobrenome_do_Cliente"; break;
case "Data_iniziale":  				$messaggio = "Data_Inicial"; break;
case "Data_finale":  				$messaggio = "Data_Final"; break;
case "Tariffa_completa":  			$messaggio = "Tarifa_completa"; break;
case "Caparra":  				$messaggio = "Depósito"; break;
case "Pagato":  				$messaggio = "Pago"; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "Pers":  					$messaggio = "Pess"; break;
case "Inserito da":  				$messaggio = "Inserido por"; break;
case "Si considererà l'utente":  		$messaggio = "Considerar o usuário"; break;
case "come colui che ha inserito il cliente":	$messaggio = "como aquele que inseriu o cliente"; break;
case "Cliente cancellato":  			$messaggio = "Cliente apagado"; break;
case "Cancella il cliente":  			$messaggio = "Apagar cliente"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Este cliente não pode ser apagado porque ele ainda está associado a algumas reservas ativas"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Você tem certeza que deseja <div style=\"display: inline; color: red;\">apagar</div> o cliente"; break;
case "SI":  					$messaggio = "SIM"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Região de residência"; break;
case "Documento":  				$messaggio = "Documento"; break;
case "Scadenza documento":  			$messaggio = "Validade do documento"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "A região de residência será alterada de"; break;
case "Il documento verrà cambiato da":  	$messaggio = "O documento será alterado de"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "A data de validade do documento será alterada de"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "A <b>região de residência</b> será apagada"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "O <b>documento</b> será apagado"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "A <b>data de validade do documento</b> será apagada"; break;
case "Cittadinanza":  				$messaggio = "Nacionalidade"; break;
case "Nazione di nascita":  			$messaggio = "País de nascimento"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Região de nascimento"; break;
case "Città di nascita":  			$messaggio = "Cidade de nascimento"; break;
case "Città di rilascio":  			$messaggio = "Cidade de emissão"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Região de emissão"; break;
case "Nazione di rilascio":  			$messaggio = "País de emissão"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "A nacionalidade será alterada de"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "O país de nascimento será aletrado de"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "A região de nascimento será alterada de"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "A cidade de nascimento será alterada de"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "A cidade de emissão do documento será alterada de"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "A região de emissão do documento será alterada de"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "O país de emissão do documento será alterado de"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "A <b>nacionalidade</b> será apagada"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "O <b>país de nascimento</b> será apagado"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "A <b>região de nascimento</b> será apagada"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "A <b>cidade de nascimento</b> será apagada"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "A <b>cidade de emissão do documento</b> será alterada"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "A <b>região de emissão do documento</b> será apagado"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "O <b>país de emissão do documento</b> será apagado"; break;
case "Codice fiscale":  			$messaggio = "Código fiscal"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "O código fiscal será alterado de"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "O <b>código fiscal</b> será apagado"; break;
case "Titolo":  				$messaggio = "Título"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "O título será alterado de"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "O <b>título</b> será apagado"; break;
case "Partita iva":  				$messaggio = "N° IVA"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "O número IVA será alterado de"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "O <b>número IVA</b> será apagado"; break;
case "data inserimento":  			$messaggio = "data de inserção"; break;
case "carte di credito":  			$messaggio = "cartões de crédito"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "Senha acesso dados de cartões de crédirto"; break;
case "invia":  					$messaggio = "enviar"; break;
case "password errata":  			$messaggio = "senha errada"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "Os dados de cartõe de crédito foram apagados"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "O Número de cartão de crédito está <span class=\"colred\">errado</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "O número CVC está <span class=\"colred\">errado</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "Os dados de cartão de crédito foram acrescentados"; break;
case "carta di credito del cliente":  		$messaggio = "cartão de crédito do cliente"; break;
case "Tipo":  					$messaggio = "Tipo"; break;
case "Numero":  				$messaggio = "Número"; break;
case "Titolare":  				$messaggio = "Titular"; break;
case "Scadenza":  				$messaggio = "Validade"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "modifica i dati della carta di credito":	$messaggio = "modificar os dados do cartão de crédito"; break;
case "cancella questa carta di credito":  	$messaggio = "Apagar este cartão de crédito"; break;
case "soprannome":  				$messaggio = "Apelido"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "O apelido será alterado de"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "O <b>apelido</b> será apagado"; break;
case "Lingua":  				$messaggio = "Idioma"; break;
case "La lingua verrà cambiata da":  		$messaggio = "O idioma será alterada de"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "O <b>idioma</b> será apagado"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Os dados do cartão de crédito podem ser visualizados apenas a través de uma ligação segura SSL"; break;
case "Il campo":  				$messaggio = "O campo"; break;
case "verrà tolto":  				$messaggio = "será apagado"; break;
case "verrà modificato":  			$messaggio = "será alterado"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.zip: pt/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Modifica Cliente":  			$messaggio = "Modificar os dados do cliente"; break;
case "Il cognome verrà cambiato da":  		$messaggio = "O sobrenome será alterado de"; break;
case "a":  					$messaggio = "para"; break;
case "Il nome verrà cambiato da":  		$messaggio = "O nome  será alterado de"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "O sexo será alterado para"; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "A data do nascimento será alterada de"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "O número de telefone será alterado de"; break;
case "La via  verrà cambiata da":  		$messaggio = "A rua será alterada de"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "O número de casa será alterado de"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "A cidade de residência será alterada de"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "O país de residência será alterado de"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "O CEP será alterado de"; break;
case "Il fax verrà cambiato da":  		$messaggio = "O fax será alterado de"; break;
case "L' email verrà cambiata da":  		$messaggio = "O e-mail será alterado de"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "O 2° úmero de telefone será alterado de"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "O 3° número de telefone será alterado de"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "O <b>comentário</b> será alterado"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "O <b>nome</b> será apagado"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "A <b>data do nascimento</b> será apagada"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "O <b>telefone</b> será apagado"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "A <b>rua</b> será apagada"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "O <b>número de casa</b> será apagado"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "A <b>cidade de residência</b> será apagada"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "O <b>país de residência</b> será apagado"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "O <b>CEP</b> será apagado"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "O <b>fax</b> será apagado"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "O <b>e-mail</b> será apagado"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "O <b>2° número de telefone</b> será apagado"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "O <b>3° número de telefone</b> será apagado"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Il cliente":  				$messaggio = "O cliente"; break;
case "è stato modificato":  			$messaggio = "foi alterado"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Modifica i dati del cliente":  		$messaggio = "Alterar os dados do cliente"; break;
case "Cognome":  				$messaggio = "Sobrenome"; break;
case "cambia in":  				$messaggio = "alterar em"; break;
case "Nome":  					$messaggio = "Nome"; break;
case "cancella":  				$messaggio = "apagar"; break;
case "Sesso":  					$messaggio = "Sexo"; break;
case "Data di nascita":  			$messaggio = "Data do nascimento"; break;
case "Telefono":  				$messaggio = "Telefone"; break;
case "Via":  					$messaggio = "Rua"; break;
case "Piazza":  				$messaggio = "Praça"; break;
case "Viale":  					$messaggio = "Avenida"; break;
case "Piazzale":  				$messaggio = "Bairro"; break;
case "Vicolo":  				$messaggio = "Estrada"; break;
case "Numero civico":  				$messaggio = "Número de casa"; break;
case "Città di residenza":  			$messaggio = "Cidade de residência"; break;
case "Nazione di residenza":  			$messaggio = "País de residência"; break;
case "CAP":  					$messaggio = "CEP"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "2° telefono":  				$messaggio = "2º telefone"; break;
case "3° telefono":  				$messaggio = "3º telefone"; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "documento di tipo":  			$messaggio = "documento do tipo"; break;
case "visualizza":  				$messaggio = "visualizar"; break;
case "visualizza il documento":  		$messaggio = "visualizar documento"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reservas do cliente"; break;
case "nel":  					$messaggio = "no"; break;
case "Cognome_del_cliente":  			$messaggio = "Sobrenome do cliente"; break;
case "Data_iniziale":  				$messaggio = "Data inicial"; break;
case "Data_finale":  				$messaggio = "Data final"; break;
case "Tariffa_completa":  			$messaggio = "Tarifa completa"; break;
case "Caparra":  				$messaggio = "Depósito"; break;
case "Pagato":  				$messaggio = "Pago"; break;
case "Commento":  				$messaggio = "Comentário"; break;
case "Pers":  					$messaggio = "Pess"; break;
case "Inserito da":  				$messaggio = "Inserido por"; break;
case "Si considererà l'utente":  		$messaggio = "Considerar o usuário"; break;
case "come colui che ha inserito il cliente":	$messaggio = "como aquele que inseriu o cliente"; break;
case "Cliente cancellato":  			$messaggio = "Cliente apagado"; break;
case "Cancella il cliente":  			$messaggio = "Apagar cliente"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Este cliente não pode ser apagado porque ele ainda está associado a algumas reservas ativas"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Você tem certeza que deseja <div style=\"display: inline; color: red;\">apagar</div> o cliente"; break;
case "SI":  					$messaggio = "SIM"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Reg./Prov. de residência"; break;
case "Documento":  				$messaggio = "Documento"; break;
case "Scadenza documento":  			$messaggio = "Validade do documento"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "A região de residência será alterada de"; break;
case "Il documento verrà cambiato da":  	$messaggio = "O documento será alterado de"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "A data de validade do documento será alterada de"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "A <b>região de residência</b> será apagada"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "O <b>documento</b> será apagado"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "A <b>data de validade do documento</b> será apagada"; break;
case "Cittadinanza":  				$messaggio = "Nacionalidade"; break;
case "Nazione di nascita":  			$messaggio = "País de nascimento"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Reg./Prov. de nascimento"; break;
case "Città di nascita":  			$messaggio = "Cidade de nascimento"; break;
case "Città di rilascio":  			$messaggio = "Cidade de emissão"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Reg./Prov. de emissão"; break;
case "Nazione di rilascio":  			$messaggio = "País de emissão"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "A nacionalidade será alterada de"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "O país de nascimento será aletrado de"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "A região de nascimento será alterada de"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "A cidade de nascimento será alterada de"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "A cidade de emissão do documento será alterada de"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "A região de emissão do documento será alterada de"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "O país de emissão do documento será alterado de"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "A <b>nacionalidade</b> será apagada"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "O <b>país de nascimento</b> será apagado"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "A <b>região de nascimento</b> será apagada"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "A <b>cidade de nascimento</b> será apagada"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "A <b>cidade de emissão do documento</b> será alterada"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "A <b>região de emissão do documento</b> será apagado"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "O <b>país de emissão do documento</b> será apagado"; break;
case "Codice fiscale":  			$messaggio = "Código fiscal"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "O código fiscal será alterado de"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "O <b>código fiscal</b> será apagado"; break;
case "Titolo":  				$messaggio = "Título"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "O título será alterado de"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "O <b>título</b> será apagado"; break;
case "Partita iva":  				$messaggio = "N° IVA"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "O número IVA será alterado de"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "O <b>número IVA</b> será apagado"; break;
case "data inserimento":  			$messaggio = "data de inserção"; break;
case "carte di credito":  			$messaggio = "cartões de crédito"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "Senha acesso dados de cartões de crédirto"; break;
case "invia":  					$messaggio = "enviar"; break;
case "password errata":  			$messaggio = "senha errada"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "Os dados de cartõe de crédito foram apagados"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "O Número de cartão de crédito está <span class=\"colred\">errado</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "O número CVC está <span class=\"colred\">errado</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "Os dados de cartão de crédito foram acrescentados"; break;
case "carta di credito del cliente":  		$messaggio = "cartão de crédito do cliente"; break;
case "Tipo":  					$messaggio = "Tipo"; break;
case "Numero":  				$messaggio = "Número"; break;
case "Titolare":  				$messaggio = "Titular"; break;
case "Scadenza":  				$messaggio = "Validade"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "modifica i dati della carta di credito":	$messaggio = "modificar os dados do cartão de crédito"; break;
case "cancella questa carta di credito":  	$messaggio = "Apagar este cartão de crédito"; break;
case "soprannome":  				$messaggio = "Apelido"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "O apelido será alterado de"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "O <b>apelido</b> será apagado"; break;
case "Lingua":  				$messaggio = "Língua"; break;
case "La lingua verrà cambiata da":  		$messaggio = "A língua será alterada de"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "A <b>língua</b> será apagada"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Os dados do cartão de crédito podem ser visualizados apenas a través de uma ligação segura com protocolo https"; break;
case "Il campo":  				$messaggio = "O campo"; break;
case "verrà tolto":  				$messaggio = "será apagado"; break;
case "verrà modificato":  			$messaggio = "será modificado"; break;
case "verrà aggiunto":  			$messaggio = "será adicionado"; break;
case "scaduta":  				$messaggio = "vencido"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "Os detalhes dos cartões de crédito serão novamente acessíveis depois de alterar a senha"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "Os detalhes dos cartões de crédito serão novamente acessíveis depois que um usuário adminstrador alterou a senha"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporariamente bloqueado"; break;
case "NOTA":  					$messaggio = "NOTA"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "este valor já foi apagado, esta é a *ÚLTIMA VEZ QUE É EXIBIDO*"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "Este valor só será exibido *MAIS UMA VEZ*"; break;
case "Cancellalo ora":  			$messaggio = "Apagar agora"; break;
case "CVC cancellato":  			$messaggio = "CVC apagado"; break;
case "2ª email":  				$messaggio = "2.º e-mail"; break;
case "PEC o codice destinatario":  		$messaggio = "PEC ou código do destinatário"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "O segundo email será alterado por"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "O email certificado (PEC) ou o código do destinatário serão alterados por"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "O <b>segundo e-mail</b> será excluído"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "O <b>e-mail certificado (PEC) ou o código do destinatário</b> será excluído"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
